#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-diff
version:              1.1.0.13
visibility:           public
id:                   aeson-diff-1.1.0.13-G4wWJ65nzgMIKXetcZ1s04
key:                  aeson-diff-1.1.0.13-G4wWJ65nzgMIKXetcZ1s04
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Thomas Sutton
homepage:             https://github.com/ysangkok/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  71a9751d1d3752ea6631f908311cafa5
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-diff-1.1.0.13
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-diff-1.1.0.13
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-diff-1.1.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-diff
hs-libraries:         HSaeson-diff-1.1.0.13-G4wWJ65nzgMIKXetcZ1s04
depends:
    aeson-2.2.1.0-AeqJOB7WzlfHEyTUHodGhY base-4.18.2.1
    bytestring-0.11.5.3
    edit-distance-vector-1.0.0.4-Gr39SvTEFKI7CDpHap4aoR
    scientific-0.3.8.1-7BwanMPzFRn1JLyZrCxw2n text-2.0.2
    vector-0.13.2.0-AWRowWUrdYO1choGzrrEgg

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

